@@ -1,5 +1,5 @@
-use crate::egui::{CursorIcon, TextureId, Vec2};
-use crate::fltk::{
+use egui::{CursorIcon, TextureId, Vec2};
+use fltk::{
     app,
     enums::{self, Cursor},
     prelude::{FltkError, ImageExt, InputExt, WidgetExt, WindowExt},
@@ -11,7 +11,7 @@ pub use fltk;
 use std::{iter, num::NonZeroU32, sync::Arc, time::Instant};
 
 /// Construct the frontend.
-/// 
+///
 /// DpiScaling can be Default or Custom(f32)
 pub fn begin_with(
     window: &mut fltk::window::Window,
@@ -83,14 +83,13 @@ impl Painter {
         texture: Arc<egui::Texture>,
     ) {
         let surface = &self.surface;
-        let surface_config = &mut self.surface_config;
         let render_pass = &mut self.render_pass;
         let width = state.physical_width;
         let height = state.physical_height;
         {
-            surface_config.width = width;
-            surface_config.height = height;
-            surface.configure(&device, &surface_config);
+            self.surface_config.width = width;
+            self.surface_config.height = height;
+            surface.configure(&device, &self.surface_config);
         }
 
         // Upload all resources for the GPU.
@@ -477,7 +476,7 @@ pub fn translate_cursor(
     }
 }
 
-pub trait ImgWidgetConvert<I> {
+pub trait ImgWidgetConvert {
     /// Convert fltk Image to Egui Image Widget.
     ///
     /// label: Debug label of the texture. This will show up in graphics debuggers for easy identification.
@@ -490,7 +489,10 @@ pub trait ImgWidgetConvert<I> {
     ) -> Result<ImgWidget, FltkError>;
 }
 
-impl<I: ImageExt> ImgWidgetConvert<I> for I {
+impl<I> ImgWidgetConvert for I
+where
+    I: ImageExt,
+{
     fn to_img_widget(
         self,
         painter: &mut Painter,
